<script setup>
import { getCurrentInstance, ref, watch, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postForm } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-locDetl';

let tableData = ref([]);
let open = ref(false);
const locId = ref(null);
const showWidth = ref("60%")
getColumns();

const {
    getColumnSearchProps,
} = useTableSearch();

const state = reactive({
    selectedRowKeys: [],
    loading: false,
    columns: [],
});

state.columns = [
    {
        title: formatMessage('db.man_loc_detl.loc_no', '库位号'),
        dataIndex: 'locNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('locNo'),
    },
    {
        title: formatMessage('db.man_loc_detl.mat_id', '商品'),
        dataIndex: 'matId$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('matId$'),
    },
    {
        title: formatMessage('db.man_loc_detl.matnr', '商品编号'),
        dataIndex: 'matnr',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('matnr'),
    },
    {
        title: formatMessage('db.man_loc_detl.order_no', '订单号'),
        dataIndex: 'orderNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('orderNo'),
    },
    {
        title: formatMessage('db.man_loc_detl.batch', '批号'),
        dataIndex: 'batch',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('batch'),
    },
    {
        title: formatMessage('db.man_loc_detl.anfme', '数量'),
        dataIndex: 'anfme',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('anfme'),
    },
    {
        title: formatMessage('db.man_loc_detl.freeze', '是否冻结'),
        dataIndex: 'freeze$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('freeze$'),
    },
    {
        title: formatMessage('db.man_loc_detl.status', '状态'),
        dataIndex: 'status$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('status$'),
    },
    // {
    //   title: formatMessage('db.man_loc_detl.create_time', '添加时间'),
    //   dataIndex: 'createTime$',
    //   width: 140,
    //   ellipsis: true,
    //   ...getColumnSearchProps('createTime$'),
    // },
    // {
    //   title: formatMessage('db.man_loc_detl.create_by', '添加人员'),
    //   dataIndex: 'createBy$',
    //   width: 140,
    //   ellipsis: true,
    //   ...getColumnSearchProps('createBy$'),
    // },
    {
        title: formatMessage('db.man_loc_detl.update_time', '修改时间'),
        dataIndex: 'updateTime$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('updateTime$'),
    },
    {
        title: formatMessage('db.man_loc_detl.update_by', '修改人员'),
        dataIndex: 'updateBy$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('updateBy$'),
    },
    {
        title: formatMessage('db.man_loc_detl.memo', '备注'),
        dataIndex: 'memo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('memo'),
    },
];

const fieldList = [];
//加载扩展字段
async function getColumns() {
    let fieldResp = await post('/api/matField/list', {
        fieldType: 1
    })
    let fieldResult = fieldResp.data;
    let tmp = state.columns;
    if (fieldResult.code == 200) {
        let data = fieldResult.data;

        data.forEach((item) => {
            tmp.push({
                title: formatMessage(item.language, item.describe),
                name: item.name,
                dataIndex: item.name,
                key: item.name,
                width: 140,
                editable: true,
            })

            fieldList.push(item.name);
        })

        // tmp.push({
        //     title: formatMessage('common.operation', '操作'),
        //     name: 'oper',
        //     dataIndex: 'oper',
        //     key: 'oper',
        //     width: 140,
        // })

        state.columns = tmp;
    } else if (result.code === 401) {
        message.error(result.msg);
        logout()
    } else {
        message.error(result.msg);
    }
}

const handleOk = () => {
    open.value = false;
}

const handleCancel = () => {
    open.value = false;
    locId.value = null;
}

watch(locId, (newVal, oldVal) => {
    if (newVal != null) {
        get("/api/locDetl/locId/" + newVal, {}).then((resp) => {
            let result = resp.data;
            tableData.value = result.data;
        })
    }
})

defineExpose({
    tableData,
    locId,
    open,
    showWidth,
})

</script>

<script>
export default {
    name: 'showLocDetlComponent'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open" :width="showWidth" @ok="handleOk" @cancel="handleCancel">
            <a-table :data-source="tableData" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
                :scroll="{ y: 768 }" :columns="state.columns">
                <template #bodyCell="{ column, text, record }">
                    <template v-if="column.dataIndex === 'workQty'">
                        <a-button type="link" @click="openWorkTask(record)">{{ text }}</a-button>
                    </template>

                    <template v-if="column.dataIndex === 'qty'">
                        <a-button type="link" @click="openCompleteQty(record)">{{ text }}</a-button>
                    </template>

                    <template v-if="column.dataIndex === 'waitQty'">
                        <a-button type="link" @click="openWaitQty(record)">{{ text }}</a-button>
                    </template>
                </template>
            </a-table>
        </a-modal>
    </div>
</template>

<style></style>
